pub struct HealthMonitor {
pub health_score: u8,
pub issues: Vec<(HealthIssue, SeverityLevel)>,
pub recovery_attempts: u32,
pub last_check: Instant,
}Expand description
Health monitoring state
Fields
health_score: u8Overall health score (0-100, where 100 is perfect health)
issues: Vec<(HealthIssue, SeverityLevel)>Detected health issues
recovery_attempts: u32Number of recovery attempts made
last_check: InstantTimestamp of last health check (skipped for serialization as Instant is not serializable)
Implementations
Sourceimpl HealthMonitor
impl HealthMonitor
Sourcepub fn add_issue(&mut self, issue: HealthIssue)
pub fn add_issue(&mut self, issue: HealthIssue)
Add a health issue and update the health score
Sourcepub fn remove_issue(&mut self, issue: &HealthIssue)
pub fn remove_issue(&mut self, issue: &HealthIssue)
Remove a health issue and update the health score
Sourcepub fn clear_issues(&mut self)
pub fn clear_issues(&mut self)
Clear all health issues and reset to perfect health
Sourcefn recalculate_score(&mut self)
fn recalculate_score(&mut self)
Recalculate health score based on current issues
Sourcepub fn is_healthy(&self) -> bool
pub fn is_healthy(&self) -> bool
Check if the system is healthy (score >= 70)
Sourcepub fn is_critical(&self) -> bool
pub fn is_critical(&self) -> bool
Check if the system is in critical state (score < 50)
Sourcepub fn issues_by_severity(&self, severity: SeverityLevel) -> Vec<&HealthIssue>
pub fn issues_by_severity(&self, severity: SeverityLevel) -> Vec<&HealthIssue>
Get issues by severity level
Sourcepub fn increment_recovery_attempts(&mut self)
pub fn increment_recovery_attempts(&mut self)
Increment recovery attempt counter